@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "atom-one-dark-theme" "0.4.0"
+(define-package "atom-one-dark-theme" "20260119.1824"
   "Atom One Dark color theme."
   ()
   :url "https://github.com/jonathanchu/atom-one-dark-theme"
-  :commit "c2ae343971f8cda7f5b5392552ce9281f52e53de"
-  :revdesc "0.4.0-0-gc2ae343971f8"
+  :commit "bba02fb2672a4c439d71920d8e068a3ff2ed463e"
+  :revdesc "bba02fb2672a"
   :authors '(("Jonathan Chu" . "me@jonathanchu.is"))
   :maintainers '(("Jonathan Chu" . "me@jonathanchu.is")))
